clashroyale
===========

.. image:: https://img.shields.io/pypi/v/clashroyale.svg
    :target: https://pypi.org/project/clashroyale/
    :alt: PyPi

.. image:: https://img.shields.io/pypi/pyversions/clashroyale.svg
    :target: https://pypi.org/project/clashroyale/
    :alt: Supported Versions

.. image:: https://travis-ci.com/cgrok/clashroyale.svg?branch=master
    :target: https://travis-ci.com/cgrok/clashroyale
    :alt: Travis CI Status

.. image:: https://img.shields.io/github/license/cgrok/clashroyale.svg
    :target: https://github.com/cgrok/clashroyale/blob/master/LICENSE
    :alt: MIT License


This library is currently an (a)sync wrapper for
https://royaleapi.com and the official Clash Royale API with
great functionality.

Installation
============

Development build

.. code-block:: python

    pip install git+https://github.com/cgrok/clashroyale

Stable build

.. code-block:: python

    pip install clashroyale

Documentation
=============

Hosted on readthedocs.io (https://clashroyale.readthedocs.io)

Docstrings are written using the `NumpyDoc`_ specification

.. _NumpyDoc: https://github.com/cdgriffith/Box